"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../lib/util");
const queryUtils_1 = require("../lib/queryUtils");
const errors_1 = require("../lib/errors");
const defaultQueries_json_1 = __importDefault(require("../defaultQueries.json"));
const queriesController = (_db, service, urlPrefix) => {
    service.app.get(`${urlPrefix}/queries`, service.identityManager.authenticateRequest(), util_1.accessCheck(service), util_1.asyncWrapper(async (req, res, _next) => {
        const { project, universe } = req.query;
        const allQueries = defaultQueries_json_1.default.queries;
        const layouts = allQueries.reduce((acc, q) => {
            for (const breakpoint in q.layouts) {
                acc[breakpoint] = acc[breakpoint] || [];
                acc[breakpoint].push(q.layouts[breakpoint]);
            }
            return acc;
        }, {});
        return res.status(200).json({
            version: process.env.npm_package_version,
            project_name: project,
            universe_name: universe,
            queries: allQueries,
            layouts,
        });
    }));
    service.app.post(`${urlPrefix}/queries/:id`, service.identityManager.authenticateRequest(), util_1.accessCheck(service), util_1.asyncWrapper(async (req, res, _next) => {
        const token = req.headers['x-coroner-token'];
        if (!token) {
            return res.status(401).send(errors_1.getError(2, 'Please provide a coroner token'));
        }
        const { project, universe } = req.query;
        const { filter, order, versionAttribute, group, } = req.body;
        const coronerUrl = util_1.getCoronerUrl(universe, service, req);
        const id = parseInt(req.params.id, 10);
        const queryItem = defaultQueries_json_1.default.queries.find((query) => {
            return query.id === id;
        });
        const apiConfigData = await util_1.getApiConfig(req, token, service, universe);
        const queryOverrides = {
            filter,
            order,
            versionAttribute,
            group,
        };
        const [queryForRequest, crdbResp] = await queryUtils_1.execQuery(queryItem, queryOverrides, coronerUrl, token, project, universe, apiConfigData);
        return res.status(200).json(Object.assign({ query: queryForRequest }, crdbResp));
    }));
};
exports.default = queriesController;
//# sourceMappingURL=queries.js.map