"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchBPGGet = exports.GET_METRICS_GROUPS = exports.GET_UNIQUE_AGGREGATIONS = exports.fetchConfig = exports.fetchDescribe = exports.fetchCrdb = void 0;
const querystring_1 = __importDefault(require("querystring"));
const node_fetch_1 = __importDefault(require("node-fetch"));
const backtraceParserGenerator_1 = require("./backtraceParserGenerator");
async function fetchCrdb(token, url, project_name, req_body) {
    const res = await node_fetch_1.default(`${url}/api/query?project=${project_name}`, {
        headers: {
            accept: '*/*',
            'accept-language': 'en-US,en;q=0.9',
            'cache-control': 'no-cache',
            'content-type': 'application/json',
            pragma: 'no-cache',
            'x-coroner-location': url,
            'x-coroner-token': token,
        },
        body: req_body,
        method: 'POST',
    });
    return {
        response: await res.json(),
        status: res.status,
        statusText: res.statusText,
    };
}
exports.fetchCrdb = fetchCrdb;
async function fetchDescribe(url, token, project, table) {
    const response = await node_fetch_1.default(`${url}/api/query?${querystring_1.default.stringify({
        action: 'describe',
        project: project,
        table: table,
    })}`, {
        headers: {
            accept: '*/*',
            'accept-language': 'en-US,en;q=0.9',
            'cache-control': 'no-cache',
            'content-type': 'application/json',
            pragma: 'no-cache',
            'x-coroner-location': url,
            'x-coroner-token': token,
        },
        body: JSON.stringify({ action: 'describe' }),
        method: 'POST',
    });
    const data = await response.json();
    if (data && data.describe && Array.isArray(data.describe)) {
        return data.describe;
    }
    else {
        return [];
    }
}
exports.fetchDescribe = fetchDescribe;
async function fetchConfig(url, token) {
    const response = await node_fetch_1.default(`${url}/api/config`, {
        headers: {
            accept: '*/*',
            'accept-language': 'en-US,en;q=0.9',
            'cache-control': 'no-cache',
            'content-type': 'application/json',
            pragma: 'no-cache',
            'x-coroner-location': url,
            'x-coroner-token': token,
        },
        method: 'GET',
    });
    const data = await response.json();
    return data;
}
exports.fetchConfig = fetchConfig;
const UNIQUE_AGGREGATIONS = 'configuration/unique_aggregations';
const METRIC_GROUPS = 'configuration/metric_groups';
exports.GET_UNIQUE_AGGREGATIONS = {
    action: 'get',
    type: UNIQUE_AGGREGATIONS,
};
exports.GET_METRICS_GROUPS = {
    action: 'get',
    type: METRIC_GROUPS,
};
function getActionFromResponse(results, action) {
    return results[backtraceParserGenerator_1.actionToKey(action)].data;
}
async function fetchBPGGet(url, token, action) {
    const response = await backtraceParserGenerator_1.makeRequest(url, token, [action]);
    const parsedResponse = await response.json();
    const results = backtraceParserGenerator_1.parseResponse(parsedResponse);
    return getActionFromResponse(results, action);
}
exports.fetchBPGGet = fetchBPGGet;
//# sourceMappingURL=coronerdUtils.js.map